@@ -16,6 +16,7 @@ class ManyToManyBackendTestCase(ArmSectionsTestCase):
         super(ManyToManyBackendTestCase, self).setUp()
 
         self.sports = Section.objects.get(slug='sports')
+        self.pro_sports = Section.objects.get(slug='pro')
 
         self.article = Article.objects.create(
                 title="Test Article",
@@ -28,6 +29,12 @@ class ManyToManyBackendTestCase(ArmSectionsTestCase):
             )
         self.article2.sections = [self.sports]
 
+        self.subsection_article = Article.objects.create(
+                title="Subsection Article",
+                slug='subsection_article',
+            )
+        self.subsection_article.sections = [self.sports, self.pro_sports]
+
     def test_backend_with_articles(self):
         """
         Test fetching items for content with a many-to-many relationship to sections.
@@ -36,6 +43,13 @@ class ManyToManyBackendTestCase(ArmSectionsTestCase):
             self.assert_(self.article in self.sports.items)
             self.assert_(self.article2 in self.sports.items)
 
+    def test_article_in_section_and_subsection_appears_once_in_section(self):
+        with override_settings(ARMSTRONG_SECTION_ITEM_MODEL='armstrong.core.arm_sections.tests.arm_sections_support.models.Common'):
+            article_in_sports = [article for article in self.sports.items if article.slug == self.subsection_article.slug]
+            article_in_pro_sports = [article for article in self.pro_sports.items if article.slug == self.subsection_article.slug]
+            self.assertEquals(len(article_in_sports), 1)
+            self.assertEquals(len(article_in_pro_sports), 1)
+
 
 class ForeignKeyBackendTestCase(ArmSectionsTestCase):
     def setUp(self):
@@ -69,6 +83,7 @@ class ComplexBackendTestCase(ArmSectionsTestCase):
         super(ComplexBackendTestCase, self).setUp()
 
         self.pro_sports = Section.objects.get(slug='pro')
+        self.sports = Section.objects.get(slug='sports')
         self.weather = Section.objects.get(slug='weather')
 
         self.complex_article = ComplexArticle.objects.create(
@@ -76,7 +91,7 @@ class ComplexBackendTestCase(ArmSectionsTestCase):
                 slug='test_complex_article',
                 primary_section=self.pro_sports
             )
-        self.complex_article.related_sections = [self.weather]
+        self.complex_article.related_sections = [self.weather, self.sports]
 
     def test_backend_with_complex_articles(self):
         """
@@ -86,6 +101,14 @@ class ComplexBackendTestCase(ArmSectionsTestCase):
             self.assert_(self.complex_article in self.pro_sports.items)
             self.assert_(self.complex_article in self.weather.items)
 
+    def test_backend_with_complex_articles_for_no_duplicates(self):
+        """
+        Ensure that there aren't duplicate items when querying complex backends
+        """
+        with override_settings(ARMSTRONG_SECTION_ITEM_MODEL='armstrong.core.arm_sections.tests.arm_sections_support.models.ComplexCommon'):
+            self.assertEquals(len(self.pro_sports.items), 1)
+            self.assertEquals(len(self.weather.items), 1)
+
 class HierarchyBackendTestCase(ArmSectionsTestCase):
     def setUp(self):
         super(HierarchyBackendTestCase, self).setUp()
